/** 
 * Function prototypes and structures for handling the streams used by the 
 * program to read data from.
 *
 * @author Tomas Berndtsson <tomas@nocrew.org>
 */

#ifndef _PROTOCOL_PROTOCOL_H_
#define _PROTOCOL_PROTOCOL_H_

/*
 * Copyright (C) 1999, Tomas Berndtsson <tomas@nocrew.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <sys/types.h>

/**
 * Contains information taken from the HTTP response headers.
 *
 * @member return_code The return code for the request.
 * @member return_message The return message, if there was one together
 * @member return_message with the return code.
 * @member content_type The full content type string, if one was provided
 * @member content_type for this particular stream. NULL otherwise.
 * @member content_length The length of the data in the stream, or a negative
 * @member content_length if it was not given in the headers.
 * @member server A string identifying the server we are currently talking to.
 * @member server NULL, if the server wished to remain anonymous.
 * @member real_url Not really a response header, but it seems approrpiate to 
 * @member real_url store the real URL which was used for reading here.
 */
struct protocol_http_headers {
  int return_code;
  char *return_message;
  char *content_type_major;
  char *content_type_minor;
  size_t content_length;
  char *server;
  char *real_url;
};

/* Function prototypes. */
int protocol_open(char *url, char *referer, char *base_url);
int protocol_close(int fd);
struct protocol_http_headers *protocol_get_headers(int fd);

#endif /* _PROTOCOL_PROTOCOL_H_ */
