/** 
 * Structures containing settings that inflicts upon the different parts
 * of Zen. This is a generic settings area, common for all user interfaces
 * or does not affect any user interface.
 *
 * @author Tomas Berndtsson <tomas@nocrew.org>
 */

#ifndef _SETTINGS_H_
#define _SETTINGS_H_

/*
 * Copyright (C) 1999, Tomas Berndtsson <tomas@nocrew.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/**
 * Contains settings which will bother us throughout all the execution
 * of this program.
 *
 * @member dump_source A non-zero value means we will just dump the plain 
 * @member dump_source source from the stream, without any parsing at all.
 * @member interface A string containing the short name of the user interface
 * @member interface that will be used, or NULL if none was specified in 
 * @member interface which case the default interface is to be used.
 */
struct zen_settings {
  int dump_source;
  char *interface;
};

/* External declaration of the actual settings. */
extern struct zen_settings settings;

#endif /* _SETTINGS_H_ */
