/**
 * Functions to contruct and assist the user interfaces with information.
 *
 * @author Tomas Berndtsson <tomas@nocrew.org>
 */

/*
 * Copyright (C) 1999, Tomas Berndtsson <tomas@nocrew.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdio.h>

#include "ui.h"
#include "zen_ui.h"
#include "retrieve.h"
#include "threads.h"

/**
 *
 */
static void *threaded_request_page(void *arguments)
{
  char *url, *referer;
  struct layout_part *new_page;
  
  url = ((char **)arguments)[0];
  referer = ((char **)arguments)[1];

  new_page = retrieve_page(url, referer);
  thread_give_response(THREAD_RESPONSE_NEW_PAGE, (void *)new_page);

  return NULL;
}

/**
 *
 */
static int ui_functions_request_page(char *url, char *referer)
{
  static char *arguments[2];
  int ret;

  arguments[0] = url;
  arguments[1] = referer;

  /* First kill off all old page requests. */
  thread_kill(THREAD_TYPE_GET_PAGE);

  ret = thread_start(THREAD_TYPE_GET_PAGE, threaded_request_page, 
		     (void *)arguments);

  return ret;
}

/**
 *
 */
static struct layout_part *ui_functions_poll_page(void)
{
  struct layout_part *new_page = NULL;
  
  if(thread_check_response(THREAD_RESPONSE_NEW_PAGE, (void **)&new_page)) {
    return new_page;
  }

  return NULL;
}

/**
 * Initialize the functions that the generic interface can offer to the
 * user interfaces.
 *
 * @return a pointer to the struct containing pointers to the functions.
 */
struct zen_ui_functions *ui_functions_init(void)
{
  static struct zen_ui_functions functions;

  if(user_interface.ui_support.interaction) {
    functions.get_page = retrieve_page;
    functions.request_page = ui_functions_request_page;
    functions.poll_page = ui_functions_poll_page;    
  } else {
    functions.get_page = retrieve_page;
    functions.request_page = NULL;
    functions.poll_page = NULL;
  }
  return &functions;
}

/**
 *
 */
int ui_functions_wait(void)
{
  enum thread_command command;
  void *argument;

  command = thread_wait_command(&argument);

  switch(command) {
  case THREAD_COMMAND_GET_PAGE:
    break;

  default:
    return 1;
  }

  return 0;
}
